@@ -5,14 +5,15 @@ use pyo3::{prelude::*, types::PyBytes};
 use serde::{Deserialize, Serialize};
 use solana_sdk::{account::Account as AccountOriginal, clock::Epoch};
 use solders_macros::{common_methods, richcmp_eq_only};
+use solders_traits::{
+    impl_display, py_from_bytes_general_via_bincode, pybytes_general_via_bincode, CommonMethods,
+    PyBytesBincode, PyFromBytesBincode, RichcmpEqualityOnly,
+};
 
 use crate::{
     account_decoder::ParsedAccount,
-    impl_display,
     pubkey::Pubkey,
-    py_from_bytes_general_via_bincode, pybytes_general_via_bincode,
     tmp_account_decoder::{UiAccount, UiAccountData, UiAccountEncoding},
-    CommonMethods, PyBytesBincode, PyFromBytesBincode, RichcmpEqualityOnly,
 };
 
 /// An Account with data that is stored on chain.
@@ -178,7 +179,7 @@ impl AccountJSON {
 
 impl std::fmt::Display for AccountJSON {
     fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
-        write!(f, "{:?}", self)
+        write!(f, "{self:?}")
     }
 }
 pybytes_general_via_bincode!(AccountJSON);
