@@ -1,23 +1,20 @@
-use std::{fmt::Display, str::FromStr};
+use solders_traits::{
+    handle_py_value_err, py_from_bytes_general_via_bincode, pybytes_general_via_bincode,
+    CommonMethods, PyBytesBincode, PyFromBytesBincode, RichcmpEqualityOnly,
+};
+use std::fmt::Display;
 
-use crate::{
-    tmp_account_decoder::{
-        ParsedAccount as ParsedAccountOriginal, UiDataSliceConfig as UiDataSliceConfigOriginal,
-        UiTokenAmount as UiTokenAmountOriginal,
-    },
-    to_py_err, CommonMethods,
+use crate::tmp_account_decoder::{
+    ParsedAccount as ParsedAccountOriginal, UiDataSliceConfig as UiDataSliceConfigOriginal,
+    UiTokenAmount as UiTokenAmountOriginal,
 };
 use derive_more::{From, Into};
 use pyo3::prelude::*;
+use pythonize::{depythonize, pythonize};
 use serde::{Deserialize, Serialize};
 use serde_json::Value;
 use solders_macros::{common_methods, richcmp_eq_only};
 
-use crate::{
-    py_from_bytes_general_via_bincode, pybytes_general_via_bincode, PyBytesBincode,
-    PyFromBytesBincode, RichcmpEqualityOnly,
-};
-
 /// Configuration object for limiting returned account data.
 ///
 /// Args:
@@ -47,7 +44,7 @@ impl UiDataSliceConfig {
     }
 
     pub fn __repr__(&self) -> String {
-        format!("{:#?}", self)
+        format!("{self:#?}")
     }
 }
 
@@ -73,7 +70,7 @@ pub struct ParsedAccount(ParsedAccountOriginal);
 impl RichcmpEqualityOnly for ParsedAccount {}
 impl Display for ParsedAccount {
     fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
-        write!(f, "{:?}", self)
+        write!(f, "{self:?}")
     }
 }
 pybytes_general_via_bincode!(ParsedAccount);
@@ -85,8 +82,8 @@ impl<'a> CommonMethods<'a> for ParsedAccount {}
 #[pymethods]
 impl ParsedAccount {
     #[new]
-    pub fn new(program: &str, parsed: &str, space: u64) -> PyResult<Self> {
-        let value = Value::from_str(parsed).map_err(to_py_err)?;
+    pub fn new(program: &str, parsed: &PyAny, space: u64) -> PyResult<Self> {
+        let value = handle_py_value_err(depythonize::<Value>(parsed))?;
         Ok(ParsedAccountOriginal {
             program: program.to_owned(),
             parsed: value,
@@ -101,8 +98,8 @@ impl ParsedAccount {
     }
 
     #[getter]
-    pub fn parsed(&self) -> String {
-        self.0.parsed.to_string()
+    pub fn parsed(&self, py: Python<'_>) -> PyResult<PyObject> {
+        handle_py_value_err(pythonize(py, &self.0.parsed))
     }
 
     #[getter]
@@ -118,7 +115,7 @@ pub struct UiTokenAmount(UiTokenAmountOriginal);
 impl RichcmpEqualityOnly for UiTokenAmount {}
 impl Display for UiTokenAmount {
     fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
-        write!(f, "{:?}", self)
+        write!(f, "{self:?}")
     }
 }
 pybytes_general_via_bincode!(UiTokenAmount);
