@@ -1,9 +1,10 @@
 use pyo3::prelude::*;
 use solana_sdk::signer::{presigner::Presigner as PresignerOriginal, Signer as SignerTrait};
 use solders_macros::{pyhash, richcmp_signer};
+use crate::{Pubkey, Signature};
 
-use crate::{
-    handle_py_err, impl_display, impl_signer_hash, Pubkey, PyHash, RichcmpSigner, Signature,
+use solders_traits::{
+    handle_py_err, impl_display, impl_signer_hash, PyHash, RichcmpSigner,
     SignerTraitWrapper, ToSignerOriginal,
 };
 
@@ -84,7 +85,7 @@ impl Presigner {
     }
 
     fn __repr__(&self) -> String {
-        format!("{:#?}", self)
+        format!("{self:#?}")
     }
 }
 
