@@ -2,16 +2,13 @@
 use crate::{
     commitment_config::{CommitmentConfig, CommitmentLevel},
     message::Message,
-    py_from_bytes_general_via_cbor, pybytes_general_via_cbor, to_py_err,
     transaction::Transaction,
-    CommonMethods, Pubkey, PyBytesCbor, PyErrWrapper, PyFromBytesCbor, RichcmpEqualityOnly,
+    Pubkey,
 };
-use pyo3::{
-    create_exception,
-    exceptions::{PyException, PyValueError},
-    prelude::*,
-    types::PyTuple,
-    PyTypeInfo,
+use pyo3::{exceptions::PyValueError, prelude::*, types::PyTuple, PyTypeInfo};
+use solders_traits::{
+    py_from_bytes_general_via_cbor, pybytes_general_via_cbor, to_py_err, CommonMethods,
+    PyBytesCbor, PyFromBytesCbor, RichcmpEqualityOnly,
 };
 extern crate base64;
 use crate::rpc::tmp_config::{
@@ -37,13 +34,6 @@ use super::config::{
     TransactionLogsFilterWrapper,
 };
 
-create_exception!(
-    solders,
-    SerdeJSONError,
-    PyException,
-    "Raised when an error is encountered during JSON (de)serialization."
-);
-
 macro_rules! rpc_impl_display {
     ($ident:ident) => {
         impl std::fmt::Display for $ident {
@@ -179,12 +169,6 @@ unsubscribe_def!(SlotsUpdatesUnsubscribe);
 unsubscribe_def!(RootUnsubscribe);
 unsubscribe_def!(VoteUnsubscribe);
 
-impl From<serde_json::Error> for PyErrWrapper {
-    fn from(e: serde_json::Error) -> Self {
-        Self(SerdeJSONError::new_err(e.to_string()))
-    }
-}
-
 #[derive(Deserialize, Serialize, PartialEq, Eq, Clone, Debug, Default)]
 pub enum V2 {
     #[default]
@@ -738,7 +722,7 @@ impl From<Message> for MessageBase64 {
 
 impl From<MessageBase64> for Message {
     fn from(m: MessageBase64) -> Self {
-        let bytes = base64::decode(&m.0).unwrap();
+        let bytes = base64::decode(m.0).unwrap();
         bincode::deserialize::<MessageOriginal>(&bytes)
             .unwrap()
             .into()
@@ -2267,7 +2251,7 @@ impl From<Transaction> for TransactionBase64 {
 
 impl From<TransactionBase64> for Transaction {
     fn from(tx: TransactionBase64) -> Self {
-        let bytes = base64::decode(&tx.0).unwrap();
+        let bytes = base64::decode(tx.0).unwrap();
         bincode::deserialize::<TransactionOriginal>(&bytes)
             .unwrap()
             .into()
