@@ -1,6 +1,10 @@
 #![allow(clippy::too_many_arguments)]
 use derive_more::{From, Into};
 extern crate base64;
+use pythonize::{depythonize, pythonize};
+use solders_traits::{
+    handle_py_value_err, CommonMethods, PyBytesBincode, PyFromBytesBincode, RichcmpEqualityOnly,
+};
 use std::fmt::Display;
 use std::str::FromStr;
 
@@ -32,7 +36,7 @@ use crate::{
         UiTransactionTokenBalance as UiTransactionTokenBalanceOriginal,
     },
     transaction::{TransactionVersion, VersionedTransaction},
-    CommonMethods, PyBytesBincode, PyFromBytesBincode, RichcmpEqualityOnly, SolderHash,
+    SolderHash,
 };
 use pyo3::{
     prelude::*,
@@ -56,8 +60,8 @@ macro_rules! transaction_status_boilerplate {
                 write!(f, "{:?}", self)
             }
         }
-        crate::pybytes_general_via_bincode!($name);
-        crate::py_from_bytes_general_via_bincode!($name);
+        solders_traits::pybytes_general_via_bincode!($name);
+        solders_traits::py_from_bytes_general_via_bincode!($name);
         impl<'a> CommonMethods<'a> for $name {}
     };
 }
@@ -296,13 +300,14 @@ transaction_status_boilerplate!(ParsedInstruction);
 #[pymethods]
 impl ParsedInstruction {
     #[new]
-    fn new(program: String, program_id: Pubkey, parsed: &str) -> Self {
-        ParsedInstructionOriginal {
+    fn new(program: String, program_id: Pubkey, parsed: &PyAny) -> PyResult<Self> {
+        let value = handle_py_value_err(depythonize::<Value>(parsed))?;
+        Ok(ParsedInstructionOriginal {
             program,
             program_id: program_id.to_string(),
-            parsed: Value::from_str(parsed).unwrap(),
+            parsed: value,
         }
-        .into()
+        .into())
     }
 
     #[getter]
@@ -316,8 +321,8 @@ impl ParsedInstruction {
     }
 
     #[getter]
-    pub fn parsed(&self) -> String {
-        self.0.parsed.to_string()
+    pub fn parsed(&self, py: Python<'_>) -> PyResult<PyObject> {
+        handle_py_value_err(pythonize(py, &self.0.parsed))
     }
 }
 
